#
# spec file for package gns3-server
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


# Filter auto-generated deps from bundled shell script (which depends on busybox only)
%global __requires_exclude_from ^%{python3_sitelib}/gns3server/compute/docker/resources/.*$

%define gns3_user _gns3
%define gns3_group _gns3
%define gns3_home %{_sharedstatedir}/gns3
Name:           gns3-server
Version:        2.2.44.1
Release:        2.3
Summary:        A graphical network simulator
License:        GPL-3.0-or-later
Group:          Productivity/Networking/Other
URL:            https://gns3.com/
Source0:        https://github.com/GNS3/gns3-server/archive/v%{version}.tar.gz#/%{name}-%{version}.tar.gz
Source1:        %{name}-rpmlintrc
Source2:        %{name}.service
BuildRequires:  busybox
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
BuildRequires:  python3-pip
BuildRequires:  python3-setuptools
BuildRequires:  python3-wheel
Requires:       busybox
Requires:       cpulimit
Requires:       docker
Requires:       dynamips >= 0.2.11
Requires:       iouyap
Requires:       python3-Jinja2 >= 3.0.1
Requires:       python3-aiofiles >= 0.7
Requires:       python3-aiohttp >= 3.8.3
Requires:       python3-aiohttp_cors >= 0.7.0
Requires:       python3-async_timeout >= 4.0.2
Requires:       python3-distro >= 1.6.0
Requires:       python3-jsonschema >= 3.2.0
Requires:       python3-platformdirs
Requires:       python3-psutil >= 5.8.0
Requires:       python3-py-cpuinfo >= 8.0.0
Requires:       python3-sentry-sdk >= 1.12.1
Requires:       python3-truststore
%if 0%{?python3_version_nodots} < 39
Requires:       python3-importlib-resources >= 1.3
%endif
Requires:       qemu
Requires:       ubridge >= 0.9.14
Requires:       vpcs >= 0.5b1
Requires:       wireshark
BuildArch:      noarch
%if 0%{?suse_version}
Recommends:     virtualbox
%endif
Requires(pre):  shadow
%{?systemd_ordering}
Provides:       group(%gns3_group)
Provides:       user(%gns3_user)

%description
The GNS3 server manages emulators such as Dynamips, VirtualBox or Qemu/KVM.
Clients like the GNS3 GUI controls the server using a JSON-RPC API over Websockets.

You will need the new GNS3 GUI (gns3-gui repository) to control the server.

%prep
%autosetup -p1
find . -type f -name "*.py" -exec sed -i 's/^#!\/usr\/bin\/env python3/#!\/usr\/bin\/python3/' {} +
find . -type f -name "*.py" -exec sed -i 's/^#!\/usr\/bin\/env python/#!\/usr\/bin\/python3/' {} +
cp -f %{_bindir}/busybox gns3server/compute/docker/resources/bin/busybox
## Relax requirements
# Leap 15.2
sed -i -r 's/==/>=/g' requirements.txt
sed -i -r 's/distro>=1.7.*/distro>=1.6.0/' requirements.txt
sed -i -r 's/psutil>=5.9.4/psutil>=5.8.0/' requirements.txt
sed -i -r 's/aiofiles>=22.1.0/aiofiles>=0.7/' requirements.txt
sed -i -r 's/Jinja2>=3.1.2/jinja2>=3.0.1/' requirements.txt
sed -i -r 's/jsonschema>=4.17.3/jsonschema>=3.2.0/' requirements.txt
sed -i -r 's/py-cpuinfo>=9.0.0/py-cpuinfo>=8.0.0/' requirements.txt
sed -i -r '/setuptools/d' requirements.txt

%build
%if 0%{?suse_version} >= 1550
%python3_pyproject_wheel
%else
python3 setup.py build
%endif

%install
%if 0%{?suse_version} >= 1550
%python3_pyproject_install
%else
python3 setup.py install --root=%{buildroot} --prefix=%{_prefix}
%endif
rm %{buildroot}/%{python3_sitelib}/gns3server/static/.gitkeep
rm %{buildroot}/%{python3_sitelib}/gns3server/symbols/.gitkeep
find %{buildroot}/%{python3_sitelib}/gns3server -type f -name "*.py" -exec grep -Hl python3 {} + | xargs chmod +x
find %{buildroot}/%{python3_sitelib}/gns3server -name "*.svg" -exec chmod -x {} +
rm -rf %{buildroot}/%{python3_sitelib}/tests
rm %{buildroot}/%{python3_sitelib}/gns3server/compute/docker/resources/bin/busybox
install -D -m0644 %{SOURCE2} %{buildroot}%{_unitdir}/%{name}.service
install -d %{buildroot}%{_sbindir}
ln -s %{_sbindir}/service %{buildroot}%{_sbindir}/rc%{name}
install -d %{buildroot}/%{_sharedstatedir}/gns3
%fdupes %{buildroot}/%{python3_sitelib}

%pre
%service_add_pre %{name}.service
# Create gns3 user/group
getent group %{gns3_group} >/dev/null || groupadd -r %{gns3_group}
getent passwd %{gns3_user} >/dev/null || useradd -r -g %{gns3_group} -d %{gns3_home} -s /sbin/nologin -c "GNS3 service user" %{gns3_user}
exit 0

%post
%service_add_post %{name}.service
# Replace bundled busybox with the system one
cp -f %{_bindir}/busybox %{python3_sitelib}/gns3server/compute/docker/resources/bin/busybox

%preun
%service_del_preun %{name}.service

%postun
%service_del_postun %{name}.service

%files
%license LICENSE
%doc AUTHORS README.md
%{_bindir}/gns3server
%{_bindir}/gns3vmnet
%{_bindir}/gns3loopback
%{_sbindir}/rc%{name}
%{python3_sitelib}/gns3server
%{python3_sitelib}/gns3_server-%{version}*-info
%ghost %{python3_sitelib}/gns3server/compute/docker/resources/bin/busybox
%dir %attr(0750,%{gns3_user},%{gns3_group}) %{_sharedstatedir}/gns3
%{_unitdir}/%{name}.service

%changelog
* Fri Mar 22 2024 Atri Bhattacharya <badshah400@gmail.com>
- Add Provides for _gns3 user and group.
* Sun Nov 26 2023 malcolmlewis@opensuse.org
- Updated to version 2.2.44.1:
  * Catch exceptions when computing image checksums,
    (gh#GNS3/gns-server#2228).
  * Add freeze_support() for multiprocessing.
- Update rpmlintrc to remove unused-rpmlintrc-filter on
  python-missing-require importlib-resources.
- Add missing requires on python3-platformdirs and
  python3-truststore.
- Changes from version 2.2.44:
  * Bundle web-ui v2.2.44.
  * Non-blocking checksums computation when server starts,
    (gh#GNS3/gns-server#2228).
  * Fix timeout issue when creating Qemu disk image,
    (gh#GNS3/gns-server#2313).
  * Support for web socket console over HTTPS.
  * Add back script create_cert.sh.
  * Allow disabling hardware virtualization check.
  * Fix L2IOU "failed code signing checks" when IOU base file name
    is >= 63 characters.
  * Change "ip cef" to "no ip cef" in IOU default configs,
    (gh#GNS3/gns-server#2298).
  * Add Qemu IGB network device
  * Add Python 3.12 support.
  * Fix issue with importlib.resources.files() and Python 3.9
- Changes from version 2.2.43:
  * Force English output for VBoxManage, (gh#GNS3/gns-server#2266).
  * Automatically add vboxnet and DHCP server if not present for
    VirtualBox GNS3 VM, (gh#GNS3/gns-server#2266).
  * Fix issue with controller config saved before checking current
    version with previous one.
  * Prevent X11 socket file to be modified by Docker container.
  * Use the user data dir to store built-in appliances.
  * Catch ConnectionResetError exception when client disconnects.
* Mon Aug 21 2023 Joop Boonen <joop.boonen@opensuse.org>
- Update to 2.2.42
  https://github.com/GNS3/gns3-server/releases/tag/v2.2.42
  https://github.com/GNS3/gns3-server/releases/tag/v2.2.41
  https://github.com/GNS3/gns3-server/releases/tag/v2.2.40.1
  https://github.com/GNS3/gns3-server/releases/tag/v2.2.40
  https://github.com/GNS3/gns3-server/releases/tag/v2.2.39
* Tue Apr  4 2023 Ben Greiner <code@bnavigator.de>
- Update to 2.2.38
  * Bundle web-ui v2.2.38
  * Fix c7200_i0_log.txt is created in the current directory. Fixes
    [#2191]
  * Check swtpm version and start swtpm before qemu
  * Fix broken websocket console with Python 3.11
  * Fix "cannot reopen console". Ref #2182
  * Fix Qemu binary not set when adding appliance from template
- Update requirements
- Replace deprecated `setup.py install` call through PEP517 build
* Wed Jan 25 2023 Martin Hauke <mardnh@gmx.de>
- Update to version 2.2.37
  * Fix StreamWriter doesn't have the wait_closed() method in
    Python3.6. Fixes
  * Install built-in appliances when no previous version has been
    detected.
  * Update documentation to install gns3-server.
  * Give udhcpc executable right.
* Sat Jan 21 2023 Martin Hauke <mardnh@gmx.de>
- Update to version 2.2.36
  https://github.com/GNS3/gns3-server/releases/tag/v2.2.36
- Update to version 2.2.35
  https://github.com/GNS3/gns3-server/releases/tag/v2.2.35
- Update to version 2.2.34
  https://github.com/GNS3/gns3-server/releases/tag/v2.2.34
- Update to version 2.2.33
  https://github.com/GNS3/gns3-server/releases/tag/v2.2.33
- Update to version 2.2.32
  https://github.com/GNS3/gns3-server/releases/tag/v2.2.32
- Drop patch:
  * gns3-server-fix-requirements.patch
* Sun Apr 24 2022 Martin Hauke <mardnh@gmx.de>
- Update to version 2.2.31
  * qemu_vm.py Linked node test.
  * Fix dead link in README.rst
- Add patch:
  * gns3-server-fix-requirements.patch
* Fri Mar 18 2022 Steve Kowalik <steven.kowalik@suse.com>
- Remove python3-raven from BuildRequires, it hasn't been needed since
  2.2.9.
* Mon Dec 20 2021 Martin Hauke <mardnh@gmx.de>
- Udpate to version 2.2.28
  * Release web UI 2.2.28
    Simpler Systemd service file.
- Udpate to version 2.2.27
  * Fix unhandled KeyError exception when starting Docker container.
* Wed Oct 13 2021 Martin Hauke <mardnh@gmx.de>
- Update to version 2.2.26
  * Release web UI 2.2.26
  * Sort symbols by theme. Fixes GNS3/gns3-gui#3230
  * Fix memory percentage left warning. Fixes #1966
  * Update affinity symbols. Fixes GNS3/gns3-gui#3232
- Update to version 2.2.25
  * Fix issue preventing to use custom nested symbols.
  * Updated affinity symbols
  * Return disk usage for partition that contains the default
    project directory.
  * Explicitly require setuptools, utils/get_resource.py
    imports pkg_resources
* Mon Sep 20 2021 Johannes Segitz <jsegitz@suse.com>
- Added hardening to systemd service(s) (bsc#1181400). Modified:
  * gns3-server.service
* Wed Aug 25 2021 Martin Hauke <mardnh@gmx.de>
- Update to version 2.2.24
  * Fix issue when searching for image with relative path.
  * Fix wrong error when NAT interface is not allowed.
  * Fix incorrect Qemu binary selected when importing template.
  * Fix error when updating a link style.
  * Early support for Python3.10.
* Tue Aug 17 2021 Martin Hauke <mardnh@gmx.de>
- Update to version 2.2.23
  * Fix hostname inconsistencies during script execution
  * Add option `--without-kvm`
  * Add a `reload` server endpoint. Fixes #1926
  * Handle -no-kvm param deprecated in Qemu >= v5.2
  * Fix binary websocket access to the console
  * Change how to generate random MAC addresses
  * setup.py: prevent installing tests directory
  * Support cloning of encrypted qcow2 base image files
  * Fix VMware VM support on Linux and Windows. Fixes #1919
* Fri Jun 11 2021 Martin Hauke <mardnh@gmx.de>
- Update to version 2.2.22
  * Link style support.
  * Preserve auto_start/auto_open/auto_close when restoring
    snapshot.
  * Fix uBridge errors for cloud nodes not visible in logs.
  * Prevent directory traversal.
* Mon May 10 2021 Martin Hauke <mardnh@gmx.de>
- Update to version 2.2.21
  * Release Web-Ui v2.2.21
  * Improvements for get symbol dimensions endpoint. Ref #1885
* Fri Apr  9 2021 Martin Hauke <mardnh@gmx.de>
- Update to version 2.2.20
  * Release Web UI version 2.2.20
  * Fix packet capture with HTTPS remote server.
  * Sync appliance files and remove old ones after sync with
    online repo.
  * Fix export for missing files
  * Fix issue when trying to export temporary Dynamips files.
* Sat Mar  6 2021 Martin Hauke <mardnh@gmx.de>
- Update to version 2.2.19
  * Launch projects marked for auto open after SIGHUP is received.
  * Fix console type error when creating Ethernet switch node.
  * Upgrade Jinja to version 2.11.3.
- Update to version 2.2.18
  * SIGHUP: remove projects with an empty project directory.
  * Release Web UI 2.2.18
  * Catch OSError exception in psutil. Fixes #3127
  * Expose 'auto_open' and 'auto_start' properties in API when
    creating project.
  * Add mtools package information.
  * Fix warning: 'ide-drive' is deprecated when using recent
    version of Qemu.
  * Fix bug when starting of vpcs stopped with "quit".
  * Fix WinError 0 handling.
  * Stop uBridge if VPCS node has been terminated.
  * Allow cloned QEMU disk images to be resized before the node
    starts, by cloning the disk image in response to a resize
    request instead of waiting until the node starts.
  * Use HDD disk image as startup QEMU config disk.
  * Create config disk property false by default for Qemu templates.
  * Set default disk interface type to "none".
  * Add explicit option to automatically create or not the config
    disk. Off by default.
  * QEMU config disk support.
* Fri Dec  4 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 2.2.17
  * Close and remove projects deleted from disks after SIGHUP
    signal is received.
  * Release Web Ui 2.2.17
  * New config file options to configure the VNC console port
    range.
  * Use asyncio.all_tasks instead of deprecated method for
    Python 3.9 compatibility.
* Thu Nov  5 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 2.2.16
  * Release Web UI version 2.2.16
  * Fix wrong defaults for images_path, configs_path,
    appliances_path.
  * Use EnvironmentFile for Systemd service.
  * Fix SSL support for controller and local compute.
  * Prevent WIC to be added/removed while Dynamips router is
    running.
  * Fix bug with application id allocation for IOU nodes.
  * Allow commas in image paths and VM name for Qemu VMs.
  * Option to allocate or not the vCPUs and RAM settings for the
    GNS3 VM.
- Update to version 2.2.15
  * Fix symbol retrieval issue.
  * Fixes update() missing 2 required positional arguments:
    'name' and 'value'.
  * Fix Hyper-V based GNS3 VM WMI issue.
  * Release Web-Ui version 2020.4.0-beta.1
* Mon Sep 21 2020 Martin Hauke <mardnh@gmx.de>
- Use %%{?systemd_ordering} instead of %%{?systemd_requires}
* Fri Sep 18 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 2.2.14
  * Release Web-Ui version 2020.3.0-beta.4
  * Add '-smp sockets=1' by default for Qemu VMs.
  * Implement full restart if user reload a Qemu VM which has been
    updated. Fixes
- Update to version 2.2.13
  Server
  * Release Web-Ui 2020.3.0-beta.3
  * Fix issue when resuming Qemu VM.
* Sun Aug  9 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 2.2.12
  * Release Web-Ui version 2020.3.0-beta.2
  * Catch exception when psutil returns OSError
  * Downgrade psutil to version 5.6.7
  * Use parent directory as working directory for project
    duplication and snapshots. Fixes GNS3/gns3-gui#2909
  * Fix Key Error "vendor_id" is missing when configuring GNS3 VM
    with VirtualBox. Fixes GNS3/gns3-gui#3018
- Update to version 2.2.11
  * Fix crash when project sets 'auto_open' option and a remote
    GNS3 VM is used. Fixes GNS3/gns3-gui#3014
  * Fix Dynamips ghost image support when project contains a space.
  * Release Web-Ui version 2020.3.0-beta.1
  * Fix issue when cannot skip slots for Dynamips routers.
  * Allow tests to be run by root.
  * Update classifiers in setup.py
* Thu Jun 18 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 2.2.10
  * Don't require hardware acceleration.
  * Release Web-Ui version 2020.2.0-beta.5
  * Tests can be run with Python 3.8
  * Wait longer for x11 socket file to be created. Ref #1761
  * Show error message if IPv6 is not enabled when using SPICE console.
  * Only use jsonschema 2.6.0 on Windows and macOS.
  * Disable default integrations for sentry sdk.
  * Remove unused bytes2human function.
- Update to version 2.2.9
  * Release Web-Ui version 2020.2.0-beta.4
  * Support to activate/deactive network connection state
    replication in Qemu.
  * Possible fix for problem connecting to the GNS3 VM.
  * Option to reset or not all MAC addresses when exporting or
    duplicating a project.
  * Fix bug when changing properties for closed project.
  * Fix issues with crash reporting & bump version to 2.2.9dev2.
  * Lock listing VMs.
  * Try to fix error when listing Hyper-V VMs.
  * Catch VirtualBox errors when listing VMs.
  * Deprecate running with Python 3.5
  * aiocontextvars is only necessary for Python < 3.7
  * Replace Raven by Sentry SDK. Fixes #1758
  * Require setuptools>=17.1 in setup.py.
* Tue Jun  2 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 2.2.8
  - https://github.com/GNS3/gns3-server/releases/tag/v2.2.8
- Remove patches (not longer needed):
  * gns3-server-timeout-fix.patch
  * gns3-server-requirements-fix.patch
- Specfile cleanup
- Add systemd service file
- Filter auto-generated deps from bundled shell scripts
* Tue Aug  6 2019 Todd R <toddrme2178@gmail.com>
- This package doesn't support jsonschema 3.
* Thu Apr 18 2019 Jan Engelhardt <jengelh@inai.de>
- Trim name repetition from summary. (rpmlint would warn about this)
- Use find "-exec +" mode and remove wrong backslash.
* Wed Apr 17 2019 Joop Boonen <joop.boonen@opensuse.org>
- Added some fixes for new python module versions
  * Added gns3-server-timeout-fix.patch to fix Timeout(aiohttp.Timeout)
  * Added gns3-server-requirements-fix.patch to update the requirements
* Tue Apr 16 2019 Joop Boonen <joop.boonen@opensuse.org>
- Build version 2.1.16
  [#]# 2.1.16 15/04/2019
  * Fix broken embedded console for Ethernet switch. Fixes #1574
  * Remove old unused argument option. Fixes #1569
  [#]# 2.1.15 21/03/2019
  * Fix IOU symlink issue on remote servers.
  * Fix vcpus configuration for GNS3 VM on VMware. Ref #2738.
  [#]# 2.1.14 27/02/2019
  * Fix issue when setting cpuid.corespersocket for the GNS3 VM. Fixes https://github.com/GNS3/gns3-gui/issues/2723
  * Bump ACPI Shutdown Timeout to 120 seconds. Ref #1536
  [#]# 2.1.13 26/02/2019
  * Force jsonschema dependency to 2.6.0
  * Less aggressive connections to uBridge. Ref #1289
  * Fix topology images (Pictures) disappearing from projects. Fixes #1514.
  * Reset MAC addresses when duplicating a project. Fixes #1522
  * Fix API call to create a node from an appliance doesn't return the new node data. Fixes #1527
  * Detect invalid environment variable and send a warning when creating a Docker node. Ref #2683
  * Do not export/import symlinks for projects. Fixes #2699
  * Fix symlink not being created for duplicated IOU devices. Fixes https://github.com/GNS3/gns3-gui/issues/2699
  * Configure coresPerSocket value in VMX file for the GNS3 VM. Fixes https://github.com/GNS3/gns3-gui/issues/2688
  * Count logical CPUs to detect if the number of vCPUs is too high when configuring the GNS3 VM. Fixes #2688.
  * Add explicit error when trying to pull a Docker image from Docker Hub without Internet access. Fixes #1506.
  * Fixes double display output in GRUB in QEMU v3.1. Fixes #1516.
  [#]# 2.1.12 23/01/2019
  * Tune how to get the size of SVG images. Ref https://github.com/GNS3/gns3-gui/issues/2674.
  * Automatically create a symbolic link to the IOU image in the IOU working directory. Fixes #1484
  * Fix link pause/filters only work for the first interface of Docker containers. Fixes #1482
  * Telnet console resize support for Docker VM.
  * Fix _fix_permissions() garbles permissions in Docker VM. Ref #1428
  * Fix "None is not of type 'integer'" when opening project containing a Qemu VM. Fixes #2610.
  * Only require Xtigervnc or Xvfb+x11vnc for Docker with vnc console. Ref #1438
  * Support tigervnc in Docker VM. Ref #1438
  * Update minimum VIX version requirements for VMware. Ref #1415.
  [#]# 2.1.11 28/09/2018
  * Catch some exceptions.
  [#]# 2.1.10 15/09/2018
  * Include locale information and GNS3 VM version in crash reports.
  * Fix small errors like unhandled exceptions etc.
  * Import encodings.idna to avoid LookupError when standard library is in a zip file.
  * Catch exceptions in various locations to fix small issues reported by Sentry.
  * Check if serial pipe can be opened for VMware and VirtualBox VMs.
  * Improve the invalid port format detection. Fixes https://github.com/GNS3/gns3-gui/issues/2580
  * Update aiohttp verion requirement in order to support Python 3.7. Fixes https://github.com/GNS3/gns3-gui/issues/2566
  * Update setup.py and fix minor issues.
  * Catch asyncio.CancelledError when shutting down the server.
  * Report GNS3 VM errors to the GUI server summary. Ref #1359.
  * Replace vboxnet0 (if it does not exist) by the first available vboxnet interface on Windows. Fixes https://github.com/GNS3/gns3-vm/issues/102
  * Check if the VirtualBox host-only network exists when starting a GNS3 VM running on VirtualBox. Ref https://github.com/GNS3/gns3-vm/issues/102
  * Change file timestamps if necessary because ZIP does not support timestamps before 1980. Fixes #1360.
  * Add missing coroutine decorator Ref https://github.com/GNS3/gns3-gui/issues/2566
  * Refactor asyncio locking system for Python 3.7 support. Ref https://github.com/GNS3/gns3-gui/issues/2566 Ref https://github.com/GNS3/gns3-gui/issues/2568
  * Use asyncio.ensure_future() instead of asyncio.async() with conservative approach to support Python < 3.4.4. Fixes https://github.com/GNS3/gns3-gui/issues/2566
  * Forbid controller and compute servers to be different versions. Report last compute server error to clients and display in the server summary.
  * Fix exception with short names for Dynamips interfaces. Fixes #1386.
  * Add missing Qemu boot priority values. Fixes https://github.com/GNS3/gns3-server/issues/1385
  [#]# 2.1.9 13/08/2018
  * Fix some more problems with interface short names. Fixes https://github.com/GNS3/gns3-gui/issues/2562
  * Fix incorrect short port names in topology summary. Fixes https://github.com/GNS3/gns3-gui/issues/2562
  * Set lower process priority when computing idle-pc value on Windows. Ref #2522.
  * Catch exception: ZIP does not support timestamps before 1980. Ref #1360.
  * Sync appliances
  [#]# 2.1.8 14/06/2018
  * 'caplog.text()' syntax is deprecated, use 'caplog.text' property instead.
  * Remove problematic pytest-capturelog dev dependency.
  * Fix API status code for start/stop/suspend/reload a node. Fixes #1353. Fix issues with test. Update documentation.
  * Don't send variables to computes where are empty, Ref: #1340
  [#]# 2.1.7 12/06/2018
  * Don't release NIO UDP ports when updating docker container.
  * Timeout for stream file.
  * Fix switching console type from telnet to VNC throws error.
  * Fix timeout error with "save as" for large projects.
  * Update API documentation
  * Add API endpoint to return all links attached to a node.
  * Fix issue with some SVG symbols that could not be used in GNS3. This was due to the height and width values being percentages.
  * Show correct free disk space value.
  * Force prompt-toolkit to version 1.0.15
  * Remove unwanted trailing characters and other white spaces when reading .md5sum files.
  * Change order to find vnetlib on Windows (PATH -> Registry -> Default directories).
  [#]# 2.1.6 22/05/2018
  * Locks down async-timeout<3.0.0 for P3.4 support; Fixes: #1331
  * Create/update project on compute when variables changes
  * Support for nested global variables
  * Don't clean logo images when applied to the project
  * Support of supplier and variables in topology
  * Project global variables
  * Add command information when uBridge has an error. Ref #1289
  * Handle asyncio timeouts. Ref #1307.
  * Fix bug with export project. Ref #1187 #1307.
  * Offload slow file operations to threads for snapshots and project "save as". Ref #1187 #1307.
  * support based on init.sh, Ref: #2482
  * Fix exception from send_signal() on Windows.
  * Add support of ExtraHosts for Docker, Ref. gns3-gui#2482
  [#]# 2.1.5 18/04/2018
  * Set the first byte to 0C when generating a random MAC address for a Qemu VM. Ref #1267.
  * Update appliance files.
  * Do not use VMnet0 when allocating VMnet adapters.
  * Use SO_REUSEADDR before calling bind() where missing. Fixes #1289.
  * Do not fail a Dynamips project conversion if a file being used.
  * Catch exceptions when using AsyncioTelnetServer. Fixes #1321.
  * Grid size support for projects.
  * Remove 'include INSTALL' from MANIFEST.
  * Fix issue with start all.
  * Check for valid IP address and prevent to run on non-Windows platforms.
  * Enable UDP tunnel option and use ICMP probing by default.
  * Use the configured IP address to trace.
  * Have TraceNG start without needing cmd.exe
  [#]# 2.1.4 12/03/2018
  * Add Juniper JunOS space appliance.
  * Sync checkpoint gaia appliance template.
  * Sync appliance templates.
  * Make sure we use an IPv4 address in the remote install script.
  * Delete old pcap file when starting a new packet capture.
  * Fix bug preventing to export portable projects with IOU images.
  * Ignore invalid BPF filters. Ref #1290.
  * Different approach to handle no data returned by uBridge hypervisors. Fixes #1289.
  * Do not raise exception if Dynamips or uBridge hypervisor don't return data and are still running. Fixes #1289
  * Fix Dynamips private config not loaded into nvram when starting a router. Fixes #1313.
  * Make sure we don't try to read when opening a file in binary more. Fixes #1301.
  * Compatybility with controller, default_symbol and hover_symbol, Fixes: #2444
  * Filter snapshots directory during the snapshot, Fixes: #1297
  * Handle docker env with last empty line, Fixes: #2420
  * Require uBridge version 0.9.14 on Linux
  * Pywin32 instead of pypiwin32, Ref. #1276
  * Fix missing 'locales' package in base image
  * Implement a minimum interval between psutil calls. Fixes #2262
  * Fix error when appliance template is broken (missing fields). Fixes #1287.
  * Fix "Change of linked base VM doesn't work with templates migrated from 2.0"
  * Fix "Unable to override non-custom VMware adapter".
  * Let a project be opened when a port cannot be found (can happens if a project is corrupted).
  * Add an error message when Docker container is not ready to be started. Ref #1281.
  * Update documentation.
  * Sync appliance files.
  * Fix issue when running multiple project containing IOU nodes on the same server. Ref #1239.
  * Set first byte to 52 when generating a random MAC address for a Qemu VM. Ref #1267.
  * Update link state and save project when a link is suspended or filters are added/removed (without node properties set).
  * More generic dependency for pypiwin32, Ref. #1276
  [#]# 2.1.3 19/01/2018
  * Update appliance files.
  * Suspend for Docker nodes.
  * Unlock yarl version and multidict
  * Fix same MAC address for duplicated Qemu nodes.
  * Fix same base MAC for duplicated IOS routers. Fixes #1264.
  * Fix "Creating multiple IOU nodes at once assigns the same application id". Fixes #1239.
  * Fix "Transport selection via DSN is deprecated" message. Sync is configured with HTTPTransport.
  * Refresh CPU/RAM info every 1 second. Ref #2262.
  * Rename ethernet switch arp command to mac
  * Fix error while getting appliance list. Fixes #1258.
  * Fix UnboundLocalError: local variable 'node' referenced before assignment. Fixes #1256.
  * Default symbol must be computer.svg
  * Compatibility for old node templates (those with default_symbol and hover_symbol properties).
  * Fix problem when searching for VBoxManage. Fixes #1261.
  * Improve the search for VBoxManage.
  * Fixing race condition when starting the GNS3 VM.
  * Default VPCS name format is now PC-{0}.
  [#]# 2.1.2 08/01/2018
  * Do not show log message if configuration file doesn't exist. Fixes #1206.
  * Update API documentation
  * Update API documentation. Fixes #1253.
  * GNS3-API: implement GET for specific drawing and link Fixes #1249
  [#]# 2.1.1 22/12/2017
  * Protect variable replacement for Qemu options. Escape double quotes.
  * Add proper exception when cannot find tunnel on QEMU, Fixes: #1241
  * Increase timeout for creation of image, Ref. #2239
  * Protect variable replacement for Qemu options.
  * Do not overwrites persistent Docker volumes. Fixes #2358.
  * Allow users to see an error when the server cannot stream a PCAP file.
  * Fix issue with Qemu + SPICE when IPv4 is not enabled.
  * Warn users if the GNS3 VM and local server are not in the same subnet. Fixes #1231.
  * Add missing appliance files.
  * Update appliance files.
  * Fix auto idle-pc from preferences.
  * Keep consistance of aiohttp.web.HTTPForbidden() execution
  * Make sure connected links are removed when a node is deleted.
  * Validate idle-pc values for auto idle-pc feature.
  * Fix error when updating packet filter on stopped Docker link. Fixes #1229.
  * Remotely close telnet console. Ref #2330
  * EthernetSwitch closing connections, Ref: gui/#2330
  * Export files from remote server, Fixes: gui/#2271
  * New option: require KVM. If false, Qemu VMs will not be prevented to run without KVM.
  * Implement variable replacement for Qemu VM options.
  * Avoid duplicate "-nographic" option.
  * Show qemu-img stdout in case of an error.
  * Use the correct NVRAM amount when pushing private config to IOU.
  * Check and fix corrupt Qemu disk images. Fixes #2301.
  * Update warning messages when connecting to non custom adapter for VMware VMs.
  * Fix "Can't use VirtualBox VM when an interface is managed by VirtualBox". Fixes #2335.
  * Add low disk space warning when creating a new project.
  [#]# 2.1.0 09/11/2017
  * Fix typo in vcpus on VirtualBoxVM, fixes: #1213
  [#]# 2.1.0rc4 07/11/2017
  * Fix GNS3VM vCPUs control on VMware, fixes: #2324
  * Fix typo in sample gns3_server.conf. Fixes #1210.
  * Warning for getting endpoint of compute
  * Enable debug mode on async loop only in dev/debug mode
  * Add warning when using IOU with a hostname length above 15 characters.
  * Improve VMware VMs discovery process. Ref #1201.
  * Improve error message when IOU VM process is unexpectedly stopped.
  * Improved error message when the number of network adapters is above the maximum for VirtualBox VMs. Better support for potential future chipsets in addition of PIIX3 and ICH9.
  * Added localhost and gns3.github.io CORS
  [#]# 2.1.0rc3 19/10/2017
  * Set vhv.enable before run for VMWare 14. Fixes #1184
  * Tweak how VMware VMs are found with fallback to search in the default location for VMs.
  * QEMU: fix logging of base mac address when creating a new node
  * Sync appliance files.
  * Fix creation of an VMware VM failed with invalid JSON. Fixes #2282.
  * Endpoint for obtaining direct action on compute
  * Fix IOU detection of layer 1 keepalive support. Fixes #1183.
  * Fixes path normalization during file upload on nodes (Fixes: #2276)
  [#]# 2.1.0rc2 04/10/2017
  * Don't create directory structure during json dump. Fixes #2270
  * Add more information when qemu-img fails.
  * Fix issue with multidict when upgrading GNS3 VM to use dev channel.
  * Restore file permissions fails for volumes with soft links. Fixes #1180.
  * Use RAW sockets by default on Linux.
  * Add missing https console keyword in JSON schema. Fixes #1179.
  * Allow projects to be opened even when a node port is already used.
  [#]# 2.1.0rc1 13/09/2017
  * Fix NAT node not working on Windows. Fixes #1163.
  * Do not prevent a project to be deleted. Fixes #2237.
  [#]# 2.1.0b2 05/09/2017
  * Round-robin nodes across all available compute resources. Fixes #1165.
  * Try to improve error reporting when streaming a PCAP file. Ref #2235.
  * Use Npcap DLL on Windows when checking for uBridge version.
  * Fixes running switch console inside PyCharm terminal (Ref. #1172)
  * Load meta of the project on loading time (Fixes #2225)
  * Added checking if NIO exists (Fixes #1160)
  * Fixes NAT node not working on Windows (#1163)
  * Fixes loading project when link_id is not set (#1159)
  * Return platform value on appliances list (Fixes #2211)
  * Fixes not known category in Appliances (Fixes #1156)
  [#]# 2.1.0b1 04/08/2017
  * Sync appliances
  * Interface starting with gns3 are not display by default in the cloud
  * Catch error when something that is not the GNS3 server answer to virtualbox requests
  * Catch KeyError: <aiohttp.connector._TransportPlaceholder
  * Add a warning when you try to load and the server is not started with --local
  * Sync appliances
  * Fix permission on exited container
  [#]# 2.1.0a2 31/07/2017
  * Handle invalid appliances files
  * Sync appliances
  * Fix naming of node with a number in the name
  * Fix race condition in startup of capture
  * Fix bug when exporting debug information with multiple remote servers
  * Fix OSError when uploading images
  * Fix an error when a symbol is not available on filesystem
  * Fix ServerDisconnectedError for stop_all
  * This fix the images always included in portable project
  * Fix support of docker appliance with a usage
  * Duplicate API for ATM, Ethernet Hub and Frame Relay Switch
  * History support for console and telnet application
  * Fix IOU image upload
  * Duplicate IOU
  * Support duplicate for Docker
  * Duplicate support for qemu
  [#]# 2.1.0a1 24/07/2017
  * Packet filtering
  * Suspend a link
  * Duplicate a node
  * Move config to central server
  * Appliance templates on server
* Sat Jun 24 2017 mrueckert@suse.de
- update to 2.0.3
  https://github.com/GNS3/gns3-server/releases/tag/v2.0.1
  https://github.com/GNS3/gns3-server/releases/tag/v2.0.2
  https://github.com/GNS3/gns3-server/releases/tag/v2.0.3
* Wed May  3 2017 andrea@opensuse.org
- renamed rpmlintrc into gns3-server-rpmlintrc
* Wed May  3 2017 andrea@opensuse.org
- new upstream version 2.0.0
  * full changelog here: https://github.com/GNS3/gns3-server/releases
* Wed Aug 24 2016 andrea@opensuse.org
- New upstream version 1.5.2
  * Move utils.vmnet to gns3 namespace
  * Fix Exporting portable projects with QEMU includes base images even when selecting no.
  * Catch error when md5sum file is corrupted
  * requirements.txt : added support for newer aiohttp version
  * Improve compaction of .gns3project
  * Fix crash when winpcap is not installed
* Fri Jul  8 2016 andrea@opensuse.org
- New upstream verson 1.5.1
  * Increase the number of interface for docker
  * Add the method in the bad request answer
  * Fix a rare crash in IOU
  * Fix a crash when docker is used but not installed
  * Backport Docker node hot linking
  * Allows hot-linking for Docker containers. Ref #267
* Tue Jun 28 2016 andrea@opensuse.org
- New upstream version 1.5.0
  * Fix import of project with no disk
  * Allow for (a lot) more docker container ports. Fixes #593.
  * Raise an error if you try to use Docker on non Linux host
  * Fix a crash in Docker if daemon stop to respond
  * Fix a crash if Dynamips router has no initial configuration
  * Kill ghosts process at startup (Dynamips, VPCS, Ubridge)
* Fri Apr 29 2016 andrea@opensuse.org
- New upstream version 1.4.6
  * More robust save/restore for VirtualBox linked clone VM hard disks.
  * Prevent non linked cloned hard disks to be detached when using VirtualBox linked cloned VMs. Fixes #1184.
  * Stricter checks to match VMware version to the right vmrun (VIX library) version.
  * Also checks the VIX library version when only using the GNS3 VM running in VMware.
  * Allow only .pcap to be downloaded from remote stream API
  * Fix incrementation of qemu mac address
  * Clear warnings about using linked clones with VMware Player.
  * Alternative method to find the Documents folder on Windows.
  * Add IOU support and install config in /etc
* Mon Mar 28 2016 andrea@opensuse.org
- New upstream version 1.4.5
  * Stop the VMware VM if there is an error while setting up the network connections or console.
  * Remote install on 14.04 ubuntu
  * Include VMware VMs paths found preferences.ini
  * Allow to stop a VMware VM from GNS3 even if halted within the VM. Fixes #1118.
  * Keep Dynamips stdout log file in the project directory.
  * Get MAC addresses for host interfaces to use for filtering frames from vmnet interfaces.
  * Dynamips uuid hypervisor command is no longer supported.
  * Restart NPF service after adding vmnet adapters on Windows.
  * Support /etc/gns3/gns3_server.conf for the config
  * Improve warning if fusion is not installed or in non standard location
* Sat Feb 27 2016 andrea@opensuse.org
- New upstream version 1.4.4
  * Check if VMware Fusion is correctly installed when retrieving the VM list.
* Sat Feb 20 2016 andrea@opensuse.org
- new upstream version 1.4.3
  * changes effect only the GUI
* Mon Feb 15 2016 andrea@opensuse.org
- new upstream version 1.4.1
  * VMware raise error if version is not found
  * For topologies before 1.4 manage qemu missing
  * Fixes issue with packet capture on VMware VMs. Fixes #396.
  * Fixes concurrency issue when closing multiple VMware linked clone VMs. Fixes #410.
  * Fixes "can only use tap interfaces that both already exist and are up". Fixes #399.
  * Send machine stats via the notification stream
  * Check for /dev/kvm instead of kvm-ok
  * Show a warning when starting ASA8
  * Fix error when setting Qemu VM boot to 'cd' (HDD or CD/DVD-ROM)
  * Improve dynamips startup_config dump
  * Dump environnement to server debug log
  * Fix usage of qemu 0.10 on Windows
  * Show hostname when the hostname is missing in the iourc.txt
* Thu Jan 14 2016 andrea@opensuse.org
- New upsteam version 1.4.0
* Mon Dec 21 2015 andrea@opensuse.org
- New upstream version 1.3.13
  * Contributing instructions
  * Correctly display log messages.
  * Tentative fix for "WinError 64 The specified network name is no longer available" issues.
  * Fix minor errors reported by codacy.com
  * Add doc on how to got code coverage
  * Raise an error when you use a port outside the ranges
  * Fix asyncio error when closing the app
  * Release UDP ports when closing a Qemu VM. Fixes #323.
* Fri Oct  9 2015 andrea@opensuse.org
- New upstream version 1.3.11
* Wed Sep 16 2015 andrea@opensuse.org
- New upstream version 1.3.10
  * Catch exception when a process cannot be killed. Fixes #296.
  * Backport: fixes NAT NIO for Qemu VMs (do not launch any legacy scripts)
  * Fixes Unicode error. Fixes #290.
  * Don't delete Dynamips ROM files. They are used to restore the nvram.
* Sat Aug  8 2015 andrea@opensuse.org
- New upstream version 1.3.9
  * Backport: removes code that deletes IOS router instance files.
* Tue Jun 23 2015 andrea@opensuse.org
- new upstream version 1.3.7
  * client side improvements only. Server version synced with client as they both have to match
* Wed Jun 17 2015 andrea@opensuse.org
- New upstream version 1.3.6
  * Ignore invalid characters when reading the output of a process
  * Turn on / off authentication
  * Do not stop saving IOS router configs when there is an exception while a project is committed.
  * Fixed crash if a private config exist in IOS but not a private config file
  * Basic Authentication support for servers.
  * Fixed crash when Virtualbox list of VMS returns an empty line.
* Thu Jun  4 2015 andrea@opensuse.org
- New upstream version 1.3.4
  * Drop useless dependencies dateutil
  * Check if port or adapter is connected before starting/stopping a packet capture. Fixes #196.
  * Prevent users to add links to running Qemu VMs and start a capture on running VirtualBox VMs.
  * Fixes bug: couldn't set PCMCIA disk1 size for IOS routers.
  * Fix crash if you pass an invalid hostname
  * Catch VPCS kill errors
  * Raise a VirtualBox error if adapter doesn't exists
  * Ignore VirtualBox VM names with a carriage return in name
  * Cleanup the temporary project after modules have been notified of the path change
  * Do not return error if we can't remove the old project directory
  * Catch encoding errors in windows logger
  * Use setter for the qemu_path (allow to pass only the binary name)
  * Fixes TAP connection when using VPCS.
  * Fixes crash when launching Qemu on OSX from another location.
  * Adds NAT NIO in device schema validation so they can return an error that it is not supported.
* Fri May 15 2015 andrea@opensuse.org
- New upstream version 1.3.3
  * Return an error if an adapter slot doesn't exist on an IOS router.
  * NIO NAT support for VirtualBox VMs.
  * NIO NAT support for QEMU VMs (user mode back-end is used).
  * Throw an error if user put an invalid port range in config file
  * Turn off configuration parser interpolation
  * Catch configuration file parsing errors
  * Force closing the event loop to avoid warning with Python 3.4.3
  * Catch error when you can't mark a project as no longer temporary
  * Catch BrokenPipeError for OSX frozen server
  * Match how IOU initial-config is set for VPCS VM.
  * Refactors how startup-config and private-config are handled for IOS routers.
  * Catch the "WinError 0 The operation completed successfully" exception at a higher level.
  * Fix temporary project not cleanup with save as
  * If image is not found in VM directory look in images folder
  * Ordered MAC addresses for QEMU based VMs.
  * Merge remote-tracking branch 'origin/master'
  * Force utf-8 configuraton files reading
  * Do not list file starting with a . in upload handler
  * Do not crash when closing a project if VirtualBox is not accessible
  * Catch connection reset errors
  * Check for empty iourc path.
  * Fixes bugs with IOS router configs. Fixes #354.
  * Use a temporary directory as egg cache
  * Catch crash error in IOU in case of permission denied
* Fri May  1 2015 andrea@opensuse.org
- New upstream version 1.3.2
  * Cleanup the VirtualBox Media Manager after closing a project.
  * Avoid Cygwin warning with VPCS on Windows.
  * Close VirtualBox VM linked clone disks after the VM is unregistered.
  * TAP interface support for QEMU VMs.
  * Return an explicit error when a NIO type is not supported by a VM.
  * Do not erase the IOU config
  * Explicit utf-8 decoding.
  * Check NIO exists when stopping an IOU capture.
  * Fixes c7200 NPE setting.
  * Fixes VPCS process termination.
  * Catch FileNotFoundError exception in os.getcwd()
  * Fixes #270. Relative paths management with empty ones.
  * New crash report key and doesn't send report for developers
  * Catch COM errors when connecting to WMI.
  * Don't assume the PATH environment variable exists.
  * Use UUIDs instead of the VM names for VirtualBox pipe paths.
  * Add --log options for daemon support
  * Basic upstart script
  * Add qemu-kvm to the list of binary
  * Fix IOU licence check flag
  * Config paths are not used when updating Dynamips or IOU VM settings.
  * Fixes initial-configs that were not restored when opening a project containing IOU VMs.
  * Prevent parallel execution of VBox commands
  * Fix a crash when in some cases you can't access to VBOX state
  * Fix crash if VirtualBox doesn't return API version
  * Fix a crash in VirtualBox vm creation
  * Allocate random names for Dynamips NIOs.
  * Explicitly delete Dynamips NIOs and unmap VCs for ATM and Frame-Relay switches.
* Wed Apr 22 2015 mimi.vx@gmail.com
- gns-server 1.3.1 has hard dep to python3-jsonschema 2.4.0+
* Sun Apr 12 2015 andrea@opensuse.org
- New upstream version 1.3.1
  * Initial config file content can be empty (fix export issues)
  * Fix crash if IOU initial config is emtpy
  * Return more informations about bad requests for crash reports
  * Allow less strict dependencies for easier install
  * Missing project name in documentation
  * Some spring cleaning
  * Fix missing IOU documentation
  * Add missing project name in curl documentation
  * Look in old IOU images location in order to smooth transition
  * Do not overwrite initial-config IOU if client send an empty
  * Fix documentation about /ports/udp
  * Fix issues with macos X dynamips not freeing UDP port
  * Fix encoding error when saving dynamips configuration
  * The upload web page return a 200 in case of error (IE compatibility)
  * Do not crash if dynamips config contain non ascii chars
  * Test path with chinese charcaters in Qemu
  * Do not crash if no console port is available for VBox
  * Raise a DynamipsError if we can't access to VM status
  * Check name of the VBoxManage executable
  * Exclude docs and tests package from distribution
  * Catch error when qemu additional options are invalid
  * Fix ClientDisconnectedError
  * Fix crash when NIO doesn't exist
  * Turn off crash report if raven not available
  * Fix crash when IOU script file is incorrect
* Sun Apr 12 2015 andrea@opensuse.org
- New upstream version 1.3.0
  * Fix issue when asyncio read is cancelled and data is still sent by Dynamips hypervisor.
  * Fix unicode decode error when saving IOS router configs.
  * Fix error when missing adapter in Dynamips IOS router.
  * Fix crash if we call stop on dynamips on non started process.
  * Fix use_default_iou_values param was not set.
  * Fix issue when IOURC environment variable is set to None.
  * Fix issue when exporting IOS router configs.
  * Fix check if VPCS process is running.
  * Fix bug when remove_nio() is not a coroutine for ATM and FR switches.
  * Fix how to test if iou and iouyap are running.
  * Allocate a random port for Qemu monitor. Fixes issue with pre 1.3 projects.
  * Fix default chassis bug.
- removed python3-zmq from requires and buildrequired
* Wed Apr  1 2015 andrea@opensuse.org
- New upstream version 1.2.4
  * Fix issue when asyncio read is cancelled and data is still sent by Dynamips hypervisor.
  * Fix unicode decode error when saving IOS router configs.
  * Fix error when missing adapter in Dynamips IOS router.
  * Fix crash if we call stop on dynamips on non started process.
  * Fix use_default_iou_values param was not set.
  * Fix issue when IOURC environment variable is set to None.
  * Fix issue when exporting IOS router configs.
  * Fix check if VPCS process is running.
  * Fix bug when remove_nio() is not a coroutine for ATM and FR switches.
  * Fix how to test if iou and iouyap are running.
  * Allocate a random port for Qemu monitor. Fixes issue with pre 1.3 projects.
  * Fix default chassis bug.
  * Update sentry key
  * For more detailed changelog visit https://github.com/GNS3/gns3-server/releases
* Sat Jan 17 2015 andrea@opensuse.org
- New upstream version 1.2.3
  * Fixed temporary files path setting in general preferences which was not used.
  * Fixed missing devices from the node view when they use a remote server.
  * Fixed broken ASA kernel/initrd file browsers.
  * Fixed bug with WICs interfaces no showing up in the port list.
  * Fixed broken -netdev + legacy virtio in Qemu support.
- New upstream version 1.2.2
  - Small improvements / new features
  * Auxiliary console support for IOS routers.
  * Suspend / resume support for Qemu.
  * Dynamically configure network connections of running Qemu VMs (only with recent Qemu versions).
  * VPCS multi-host support (useful for old .net labs).
  * EtherSwitch routers can be added and configured like other IOS routers.
  * Change hostname option in the contextual device menu.
  * Import & export config options in contextual device menu.
  * Auto screenshot when saving a project.
  * Auto start project support (you have to manually edit your .gns3 project file).
  * Possibility to run VirtualBox as another user (Linux/OSX only).
  * Changes to the IOU L2 initial-config (16 Ethernet interfaces, no shutdown by default and 0 serial interfaces).
  * Upgraded SuperPutty to version 1.4.0.5 in the all-in-one installer.
  * Support for IOURC file on the server side.
  * Bumped the maximum network adapters to 32 for Qemu (depending on Qemu version you cannot go above 8 or
    even 28, Qemu will just not start).
  * Possibility to apply or not the same text to all selected items when editing notes.
  * Added snapshot named 'reset' to linked cloned VirtualBox VMs.
  * Base configs are now stored in the GNS3 config directory.
  * Short port names in the topology summary.
  * Added the VirtualBox VM name in VirtualBox device tooltips.
  * More network interface options to the Qemu VM configuration interface as well as descriptions for all NICs.
  * Set 5 seconds timeout for local server connections.
  * Check if any device runs and warn the user before closing a project.
  * Restore the debug level status when starting.
  * Automatically select the symbol and category corresponding the edited item in the symbol selection dialog.
  * Scale SVG images to icon sizes.
  * Console switching from local/remote to remote/local while a VirtualBox VM is running.
  * More checks on minimum RAM for IOS routers and updates default values to match the latest IOS image requirements.
  * Default Jungle dock location is now bottom right corner.
  - Bug fixes
  * Fixed the default jungle news loading on Windows.
  * Fixed SuperPutty integration (not the default, still have to select it in the preferences).
  * Avoid uninitialized nodes to be saved in the project file.
  * Fixed bug when importing Host node with UDP NIOs.
  * Prevent GNS3 to crash on Windows when importing GNS3 config file.
  * Fixed resource access on Mac OS X.
  * Fixed transparency or border style restoration for ellipses and rectangles.
  * Support spaces in the controller name of VirtualBox clones.
  * Ignore Unicode errors when executing vboxmanage.
  * Get Windows interface list from the registry if the COM service fails.
* Fri Dec 26 2014 andrea@opensuse.org
- added cpulimit to requirements
* Sat Dec  6 2014 andrea@opensuse.org
- clean up in the dependencies list.
  * qemu and wireshark are now required not just recommended
  * vde2 and xdotool have been removed, they aren't used at all
* Fri Dec  5 2014 andrea@opensuse.org
- New upstream version 1.2.1
  * Early support for IOSv and IOSv-L2 (with Qemu for now, which is slow on Windows/Mac OS X).
  * Support for CPU throttling and process priority for Qemu.
  * Support for full screen mode (View -> Fullscreen).
  * Bundled Qemu 0.13.0 in the Windows all-in-one. Default for all local Qemu VMs.
  * Bundled Qemu 0.14.1 in the Mac OS X App. Default for all local Qemu VMs.
  * Changed ASA defaults to use Qemu 0.13.0 (on Windows), have 4 interfaces and CPU throttling to 65%%.
  * Fixed SecureCRT command line when space in the device name.
  * Fixed C7200 IO cards insert/remove issues and makes C7200-IO-FE the default.
  * Fixed port sorting issues.
  * Added default path for VBoxManage on Mac OS X
  * Upgraded gns3-converter to version 1.1.1 for Windows all-in-one and Mac OS X DMG.
  * New idle-PC field validation.
  * Possibility to load the project from command line (or double-click on a project on Windows).
  * Fixed Unicode error when using VirtualBox VM with a name containing non-english characters.
  * Updated the IOU VM with iouyap version 0.95 (packet capture).
* Tue Nov 25 2014 andrea@opensuse.org
- Fixed license tag
* Sat Nov 22 2014 andrea@opensuse.org
- dropped vboxwrapper in favour of VBoxManage provided by virtualbox
* Thu Nov 20 2014 andrea@opensuse.org
- new upstream version 1.2
  * New VirtualBox support.
  * New GUI styles: charcoal (default) & classic. Changing GUI Preferences
  * Integration of GNS3 converter (allows old .net topologies to be opened).
  * VirtualBox linked clones support (experimental, still some problems with temporary projects).
  * Allow Qemu VM to have no interface.
  * Option to allow console connections to any local IP address when using the local server.
  * Automatically extract IOS configs when a project is closed.
  * Fix "new project" bug when using the GNS3 IOU VM.
  * qemu-system-i386 is the new default on 32-bit platforms.
  * Option to deactivate the new project dialog at startup.
  * Add "open a project" and "recent projects" buttons to the new project dialog.
  * New host node (cloud with all available Ethernet & TAP interfaces added).
  * Fix platform detection issue with some Cisco IOS image file name.
  * Add delay (default 500 ms) when Console to all nodes.
  * Check for duplicate node names in Preferences.
  * Fix bug when editing a Qemu VM configured to run on a remote server.
  * News dock widget is smaller.
  * Add detection of qemu and qemu.exe binaries.
  * New Telnet server for VirtualBox.
* Sat Nov 15 2014 andrea@opensuse.org
- added new dependency python3-apache-libcloud
* Thu Oct 23 2014 andrea@opensuse.org
- new upstream version 1.1
- bug fixes
  * Warning message when using a remote server with IOU
  * Serial console for VirtualBox
  * Fixes EtherSwitch router
  * New Idle-PC dialog
  * Fixes #123 (Qemu binaries list not showing up)
  * Fixes #119
  * Fixes #126 (broken remote server feature)
  * Fixes #120 (broken cloud)
* Tue Oct 21 2014 andrea@opensuse.org
- New upstream version 1.0
- New features
  * Snapshots support (currently only for local projects).
  * Possibility to configure a category for nodes (routers,
    switches, end devices or security devices).
  * Added support for xfce4-terminal, for Xubuntu.
  * Remote servers and load-balancing (some bugs, still
    things to improve).
  * Check for update feature.
  * GNS3 Jungle dock widget.
  * Getting started dialog.
  * Added path lookup directory for Qemu on OSX.
  * Bug fix when loading a project containing a remote server.
- Know issues and notes
  * VirtualBox support doesn’t work on Mac OS X.
  * VirtualBox support on other platforms hasn’t been fully tested
    and bugs may still be present.
  * Again, regarding VirtualBox integration, we have plans to rewrite
    the back-end to add more features and remove the dependency
    on vboxwrapper.
* Mon Oct 20 2014 andrea@opensuse.org
- New upstream version 1.0 Beta 4
- New features:
  * Preferences has been completely re-vamped for the
    various emulators: Dynamips, IOU, VirtualBox and Qemu.
-Know issues and notes
  * VirtualBox/QEMU on Mac OS X hasn’t been tested at all.
  * VirtualBox support on other platforms hasn’t been fully tested
  and bugs may still be present.
  * Regarding VirtualBox integration, we have plans to rewrite the
  back-end to add more features and remove the dependency on vboxwrapper.
* Thu Sep 25 2014 andrea@opensuse.org
- New upstream version 1.0 Beta 3
- New features
  * QEMU integration with ASA and IDS pre-configuration options.
  * Solarwinds Response Time Viewer integration (Windows 64-bit only).
- know issues and notes
  * VirtualBox support on other platforms hasn’t been fully tested and
    bugs may still be present.
  * Regarding VirtualBox integration, we have plans to rewrite the
    back-end to add more features and remove the dependency on vboxwrapper.
  * We still have a couple of beta releases planned before
    our first release candidate.
* Wed Sep  3 2014 andrea@opensuse.org
- New upstream version 1.0 Beta 2
  * Improved VirtualBox support on Windows and Linux.
  * VirtualBox support on Linux/OSX requires VirtualBox wrapper version >= 9.1
  * New “enable console” option for VirtualBox VMs.
  * New “start at” option for VirtualBox VMs (adapter start index, 0 by default).
  * EtherSwitch support (based on a c3745 image).
  * Multi-drop feature (use SHIFT key while dropping a new node on the drawing area).
  * Default font and color for labels.
  * Support for rectangle and ellipse color transparency.
  * New topology summary options: filter devices with capture(s) and stop all captures.
  * Commands for the GNS3 console (version, start, stop, suspend, reload, show device, show run, help and debug).
  * Layers implementation (anything below layer 0 will be locked to the drawing area).
  * Numeric sorting for Ethernet/hub ports.
  * Restore default buttons for general, packet capture and GNS3 server preferences.
  * Changed the default port ranges.
  * Normalized capture file names.
  * More checks on device names, especially for IOS and IOU which forbid some characters.
  * Handles zoom in or out using the mouse wheel + CTRL. Resets the zoom using CTRL+0.
  * Prevent node labels to be deleted.
  * The sparse memory feature is off by default for c1700 and c2600 platforms (to prevent a bug on reboot).
* Thu Jul 24 2014 andrea@opensuse.org
- New upstream version 1.0 Beta 1
  * Base VirtualBox support (still some issues, most of them on Linux and Mac OS X).
  * Prevent users to set the port and VLAN settings to 0 on Ethernet swithes.
  * Fixed issue when spaces are in capture file paths.
  * Fixed bug with live capture on Windows.
  * Work around for the c7200 reload bug in Dynamips <= 0.2.13.
  * Fixed some inconsistencies when exporting configs.
  * The early release dialog is gone!
* Thu Jul 10 2014 andrea@opensuse.org
- New upstream version 1.0 alpha 8
  * New feature: insert an image on the view.
  * New feature: change node symbols.
  * Default port configuration for Ethernet switch and hub devices.
  * New feature: import/export device configs.
  * Fixed issue when deleting note items that had parent items.
  * Check the minimum required amount of RAM when adding IOS images.
  * Start a packet capture from the device contextual menu.
  * Improvements on the topology summary and link highlighting.
  * Find an alternative IOS or IOU image if one cannot be found when importing a topology.
  * Find an alternative Ethernet interface if one cannot be found when importing a topology.
  * Use Windows interface names instead of their GUID (more user friendly).
  * Fixed IOU and VPCS renaming issues.
  * Fixed size restoration issues for rectangles and ellipses when loading a project.
  * Check for VPCS version >= 0.5b1
  * Fixed errors when connecting an IOU device to a cloud.
  * Packet capture for IOU works with the latest iouyap version (0.95) available here.
* Tue Jul  1 2014 andrea@opensuse.org
- New upstream version 1.0 alpha 7
  * Packet capture for IOS routers.
  * Packet capture for the Ethernet hub and Ethernet,
    ATM and Frame relay switches.
  * Packet capture for IOU (not working, issue with iouyap).
  * Add notes, rectangles & ellipses to topologies.
  * Show/hide interface labels.
  * Contextual device menu.
  * Recent file menu.
  * Lab instructions support (automatically open any file named
    instructions.* in the project directory or from the Help menu)
  * Load a project by dropping the project file on the view.
  * Duplicate option for notes, rectangles and ellipses.
  * Style settings for note, rectangle and ellipse items. Possibility
    to edit interface and node labels.
  * Fix: use Dynamips, IOU and VPCS identifiers to correctly
    load topologies.
  * IOU: rename startup-config to initial-config (makes more
    sense for IOU).
  * Option to uncompress IOS images.
  * Check for sticky bit when checking for executable access.
  * Fix: IOS image relative path problems.
  * Lots of small bug fixes.
* Sat May 31 2014 andrea@opensuse.org
- New upstream version 1.0 alpha 6
  * New host names management.
  * New project dialog (in preparation for cloud support).
  * Logs saved to files (GNS3_client.log and GNS3_server.log).
  * Relative paths support for IOS/IOU images in project files.
  * Fixed decoding errors when reading device configs.
  * Fixed privileged access checks for IOU.
  * Fixed validation issue with c2600 XM chassis.
  * Fixed VPCS start on Linux/UNIX.
  * Fixed Ethernet hub when loading a project.
* Thu May 22 2014 andrea@opensuse.org
- New upstream version 1.0 alpha 5
  * VPCS support (only version >= 0.5b1
  * Fixed console port errors when loading a project.
  * Fixed startup-config errors when loading a project.
  * Fixed minor issues on Mac OS X (DMG file coming soon).
  * IOU default startup-configs for layer 2 and layer 3 images.
    Allowing for faster loading times too.
  * Option to prevent starting the local server when openning the GUI.
  * Prevent devices to be started, stopped or suspended if their status is not right
  * More checks for cloud connections.
  * Show item coordinates in the status bar.
  * Amend device configs (hostname) when renaming.
  * UDP connection checks.
* Thu May 15 2014 andrea@opensuse.org
- - New upstream version 1.0 alpha 4
  * Show Windows interface names in cloud tooltips.
  * Disconnect the server if the version differs from the GUI version.
  * Move cloud code to a builtin module and support for clouds on remote servers.
  * Options to use the default IOU RAM & NVRAM values.
  * Changed the name of default base startup and private configs.
  * Added “All files” filter when looking for an IOU or IOS image in the file broswer.
  * Graceful server shutdown on Windows.
  * Error message that JIT sharing is only supported in Dynamips unstable.
  * New UDP and console port allocation system for IOU. Fixes duplicated port issues.
  * Delete some Dynamips files that are useless to save in projects.
  * Fix: the path to GNS3 server was not saved.
  * Fix: RAM and NVRAM IOU image settings not propagated when creating an IOU device.
  * Fix: bug where IOS nvram/disk files were not kept after closing a topology.
  * Fix: bug that prevented changing any IOU device setting when connected to another node.
  * Fix: duplicated node id issue.
  * Fix: major bug with ghost instance overwriting any second router files (R2).
  * Fix: error when ldd cannot be found.
  * Fix: issues with local base configs for IOS.
* Sat May  3 2014 andrea@opensuse.org
- spec file inprovements hard coding minimum required version for dependencies
- new upstream version 1.0_alpha3
  * Follow the “VMware model” to organize projects.
  * Topology files have the .gns3 extension instead of .net (they are still supported).
  * Fixed problem to capture on TAP or Ethernet interfaces when not root.
  * Updated the upload page.
  * Server request validations.
  * Graceful shutdown for the server & modules
  * Checks for valid IOS & IOU images
  * Checks for missing shared library dependencies in an IOU image.
  * Explicit error message for missing 32-bit binary support on 64-bit Linux when starting IOU.
  * Check if iouyap can access Ethernet and TAP devices.
  * Windows network interfaces support in clouds (need improvements but it works…)
  * Update tooltips to show node IDs.
  * Ranges for Dynamips UDP, console, auxiliary console and hypervisor ports.
  * Use Dynamips UDP NIO auto back-end for UDP tunnel connections (excepting stubs).
  * The GUI can check the server version.
  * Explicitly show an error if an IOS network module cannot be added or removed.
  * Support for –version on the command line for both the server and GUI.
  * Delete IOS ghost files when closing a project.
  * Check for the correct locale on Linux/UNIX.
  * Fixed bugs with duplicated node IDs.
  * Save exception.log in the same directory as the GNS3 settings file.
  * Added the view -> docks menu.
  * Checks on node ID returned by the server.
* Fri Apr 18 2014 andrea@opensuse.org
- New upstream version 1.0_alpha2
  * IOS can now communicate with IOU devices running on a different host/VM.
  * Windows topology saving/loading issues have been fixed.
  * Improved non-blocking server connections.
  * Tooltips for all devices have been added.
  * Improved address/host binding implementation.
  * No need to first “save as” before saving an IOU topology.
  * Check for the required version of Dynamips (>= 0.2.11).
  * Checks for free console and aux ports.
  * Fixed local server shutdown on Windows.
  * Fixed bugs when changing local server settings.
  * Fixed c2600 router configuration errors.
  * File upload size limit to the server has been changed from 100MB (the default) to 500MB.
  * Fixed Frame-Relay & ATM issues when loading a topology.
  * Any computed idle-pc value is applied to all routers with the same IOS image.
  * New terminal command for ROXTerm.
  * Possibility to delete nodes using the delete key.
  * Fixed GUI inconsistencies and small bugs all over the place.
* Tue Apr  1 2014 andrea@opensuse.org
- new package using git service
